@@ -2,7 +2,7 @@
  * 
  *  Gearmand client and server library.
  *
- *  Copyright (C) 2011 Data Differential, http://datadifferential.com/
+ *  Copyright (C) 2011-2013 Data Differential, http://datadifferential.com/
  *  Copyright (C) 2008 Brian Aker, Eric Day
  *  All rights reserved.
  *
@@ -45,7 +45,6 @@
 #pragma once
 
 #include <netinet/in.h>
-#include <stdbool.h>
 #include <stdlib.h>
 #include <poll.h>
 
@@ -78,6 +77,8 @@
 
 #include <libgearman-server/text.h>
 
+#include <libgearman-server/config.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -102,7 +103,8 @@ gearmand_st *Gearmand(void);
  * @return Pointer to an allocated gearmand structure.
  */
 GEARMAN_API
-gearmand_st *gearmand_create(const char *host,
+gearmand_st *gearmand_create(gearmand_config_st *config,
+                             const char *host,
                              uint32_t threads,
                              int backlog,
                              const uint32_t job_retries,
@@ -137,7 +139,8 @@ gearman_server_st *gearmand_server(gearmand_st *gearmand);
 GEARMAN_API
 gearmand_error_t gearmand_port_add(gearmand_st *gearmand,
                                    const char *port,
-                                   gearmand_connection_add_fn *function);
+                                   gearmand_connection_add_fn*,
+                                   gearmand_connection_remove_fn*);
 
 /**
  * Run the server instance.
@@ -170,6 +173,18 @@ const char *gearmand_bugreport(void);
 GEARMAN_API
 const char *gearmand_verbose_name(gearmand_verbose_t verbose);
 
+GEARMAN_API
+  gearmand_error_t gearmand_set_socket_keepalive(gearmand_st *gearmand, bool arg);
+
+GEARMAN_API
+  gearmand_error_t gearmand_set_socket_keepalive_idle(gearmand_st *gearmand, int arg);
+
+GEARMAN_API
+  gearmand_error_t gearmand_set_socket_keepalive_interval(gearmand_st *gearmand, int arg);
+
+GEARMAN_API
+  gearmand_error_t gearmand_set_socket_keepalive_count(gearmand_st *gearmand, int arg);
+
 /** @} */
 
 #ifdef __cplusplus
