@@ -48,7 +48,7 @@ using namespace libtest;
 #include <cstring>
 #include <unistd.h>
 
-#include <libgearman/gearman.h>
+#include <libgearman-1.0/gearman.h>
 #include <libgearman/connection.hpp>
 #include "libgearman/command.h"
 #include "libgearman/packet.hpp"
@@ -62,11 +62,12 @@ using namespace org::gearmand;
 
 #include "tests/start_worker.h"
 #include "tests/workers/v2/call_exception.h"
+#include "tests/workers/v2/call_exception.h"
+#include "tests/workers/v2/check_order.h"
 #include "tests/workers/v2/client_echo.h"
 #include "tests/workers/v2/echo_or_react.h"
 #include "tests/workers/v2/echo_or_react_chunk.h"
-#include "tests/workers/v2/call_exception.h"
-#include "tests/workers/v2/check_order.h"
+#include "tests/workers/v2/echo_specific_worker.h"
 
 // Port to second gearmand server
 static in_port_t second_port;
@@ -88,7 +89,7 @@ static test_return_t init_test(void *)
 {
   gearman_worker_st worker;
 
-  test_truth(gearman_worker_create(&worker));
+  ASSERT_TRUE(gearman_worker_create(&worker));
 
   gearman_worker_free(&worker);
 
@@ -99,7 +100,7 @@ static test_return_t allocation_test(void *)
 {
   gearman_worker_st *worker;
 
-  test_truth(worker= gearman_worker_create(NULL));
+  ASSERT_TRUE(worker= gearman_worker_create(NULL));
 
   gearman_worker_free(worker);
 
@@ -123,7 +124,7 @@ static test_return_t gearman_worker_clone_NULL_NULL(void *)
 {
   gearman_worker_st *worker= gearman_worker_clone(NULL, NULL);
 
-  test_truth(worker);
+  ASSERT_TRUE(worker);
   ASSERT_EQ(true, gearman_is_allocated(worker));
 
   gearman_worker_free(worker);
@@ -135,9 +136,19 @@ static test_return_t gearman_worker_clone_NULL_SOURCE(void *)
 {
   libgearman::Worker source;
 
+  gearman_function_t worker_fn= gearman_function_create(echo_specific_worker);
+  ASSERT_EQ(GEARMAN_SUCCESS, gearman_worker_define_function(&source,
+                                                            __func__, strlen(__func__),
+                                                            worker_fn,
+                                                            0,
+                                                            NULL));
+  ASSERT_EQ(true, gearman_worker_function_exist(&source, __func__, strlen(__func__)));
+
   gearman_worker_st *worker= gearman_worker_clone(NULL, &source);
-  test_truth(worker);
+  ASSERT_TRUE(worker);
   ASSERT_EQ(true, gearman_is_allocated(worker));
+  ASSERT_EQ(true, gearman_worker_function_exist(worker, __func__, strlen(__func__)));
+
   gearman_worker_free(worker);
 
   return TEST_SUCCESS;
@@ -292,13 +303,13 @@ static test_return_t option_test(void *)
   gearman_worker_options_t default_options;
 
   gearman_worker_st* gear= gearman_worker_create(NULL);
-  test_truth(gear);
+  ASSERT_TRUE(gear);
   { // Initial Allocated, no changes
-    test_truth(gearman_is_allocated(gear));
+    ASSERT_TRUE(gearman_is_allocated(gear));
     test_false(gearman_is_non_blocking(gear->impl()));
-    test_truth(gear->impl()->options.packet_init);
+    ASSERT_TRUE(gear->impl()->options.packet_init);
     test_false(gear->impl()->options.change);
-    test_true(gear->impl()->options.grab_uniq);
+    ASSERT_TRUE(gear->impl()->options.grab_uniq);
     test_false(gear->impl()->options.timeout_return);
   }
 
@@ -311,11 +322,11 @@ static test_return_t option_test(void *)
   */
   gearman_worker_set_options(gear, default_options);
   { // Initial Allocated, no changes
-    test_truth(gearman_is_allocated(gear));
+    ASSERT_TRUE(gearman_is_allocated(gear));
     test_false(gearman_is_non_blocking(gear->impl()));
-    test_truth(gear->impl()->options.packet_init);
+    ASSERT_TRUE(gear->impl()->options.packet_init);
     test_false(gear->impl()->options.change);
-    test_true(gear->impl()->options.grab_uniq);
+    ASSERT_TRUE(gear->impl()->options.grab_uniq);
     test_false(gear->impl()->options.timeout_return);
   }
 
@@ -325,21 +336,21 @@ static test_return_t option_test(void *)
   {
     gearman_worker_remove_options(gear, GEARMAN_WORKER_ALLOCATED);
     { // Initial Allocated, no changes
-      test_truth(gearman_is_allocated(gear));
+      ASSERT_TRUE(gearman_is_allocated(gear));
       test_false(gearman_is_non_blocking(gear->impl()));
-      test_truth(gear->impl()->options.packet_init);
+      ASSERT_TRUE(gear->impl()->options.packet_init);
       test_false(gear->impl()->options.change);
-      test_true(gear->impl()->options.grab_uniq);
+      ASSERT_TRUE(gear->impl()->options.grab_uniq);
       test_false(gear->impl()->options.timeout_return);
     }
 
     gearman_worker_remove_options(gear, GEARMAN_WORKER_PACKET_INIT);
     { // Initial Allocated, no changes
-      test_truth(gearman_is_allocated(gear));
+      ASSERT_TRUE(gearman_is_allocated(gear));
       test_false(gearman_is_non_blocking(gear->impl()));
-      test_truth(gear->impl()->options.packet_init);
+      ASSERT_TRUE(gear->impl()->options.packet_init);
       test_false(gear->impl()->options.change);
-      test_true(gear->impl()->options.grab_uniq);
+      ASSERT_TRUE(gear->impl()->options.grab_uniq);
       test_false(gear->impl()->options.timeout_return);
     }
   }
@@ -350,38 +361,38 @@ static test_return_t option_test(void *)
   {
     gearman_worker_remove_options(gear, GEARMAN_WORKER_NON_BLOCKING);
     { // GEARMAN_WORKER_NON_BLOCKING set to default, by default.
-      test_truth(gearman_is_allocated(gear));
+      ASSERT_TRUE(gearman_is_allocated(gear));
       test_false(gearman_is_non_blocking(gear->impl()));
-      test_truth(gear->impl()->options.packet_init);
+      ASSERT_TRUE(gear->impl()->options.packet_init);
       test_false(gear->impl()->options.change);
-      test_true(gear->impl()->options.grab_uniq);
+      ASSERT_TRUE(gear->impl()->options.grab_uniq);
       test_false(gear->impl()->options.timeout_return);
     }
     gearman_worker_add_options(gear, GEARMAN_WORKER_NON_BLOCKING);
     { // GEARMAN_WORKER_NON_BLOCKING set to default, by default.
-      test_truth(gearman_is_allocated(gear));
-      test_truth(gearman_is_non_blocking(gear->impl()));
-      test_truth(gear->impl()->options.packet_init);
+      ASSERT_TRUE(gearman_is_allocated(gear));
+      ASSERT_TRUE(gearman_is_non_blocking(gear->impl()));
+      ASSERT_TRUE(gear->impl()->options.packet_init);
       test_false(gear->impl()->options.change);
-      test_true(gear->impl()->options.grab_uniq);
+      ASSERT_TRUE(gear->impl()->options.grab_uniq);
       test_false(gear->impl()->options.timeout_return);
     }
     gearman_worker_set_options(gear, GEARMAN_WORKER_NON_BLOCKING);
     { // GEARMAN_WORKER_NON_BLOCKING set to default, by default.
-      test_truth(gearman_is_allocated(gear));
-      test_truth(gearman_is_non_blocking(gear->impl()));
-      test_truth(gear->impl()->options.packet_init);
+      ASSERT_TRUE(gearman_is_allocated(gear));
+      ASSERT_TRUE(gearman_is_non_blocking(gear->impl()));
+      ASSERT_TRUE(gear->impl()->options.packet_init);
       test_false(gear->impl()->options.change);
       test_false(gear->impl()->options.grab_uniq);
       test_false(gear->impl()->options.timeout_return);
     }
     gearman_worker_set_options(gear, GEARMAN_WORKER_GRAB_UNIQ);
     { // Everything is now set to false except GEARMAN_WORKER_GRAB_UNIQ, and non-mutable options
-      test_truth(gearman_is_allocated(gear));
+      ASSERT_TRUE(gearman_is_allocated(gear));
       test_false(gearman_is_non_blocking(gear->impl()));
-      test_truth(gear->impl()->options.packet_init);
+      ASSERT_TRUE(gear->impl()->options.packet_init);
       test_false(gear->impl()->options.change);
-      test_truth(gear->impl()->options.grab_uniq);
+      ASSERT_TRUE(gear->impl()->options.grab_uniq);
       test_false(gear->impl()->options.timeout_return);
     }
     /*
@@ -391,30 +402,30 @@ static test_return_t option_test(void *)
     {
       gearman_worker_set_options(gear, default_options);
       { // See if we return to defaults
-        test_truth(gearman_is_allocated(gear));
+        ASSERT_TRUE(gearman_is_allocated(gear));
         test_false(gearman_is_non_blocking(gear->impl()));
-        test_truth(gear->impl()->options.packet_init);
+        ASSERT_TRUE(gear->impl()->options.packet_init);
         test_false(gear->impl()->options.change);
-        test_true(gear->impl()->options.grab_uniq);
+        ASSERT_TRUE(gear->impl()->options.grab_uniq);
         test_false(gear->impl()->options.timeout_return);
       }
       gearman_worker_add_options(gear, GEARMAN_WORKER_TIMEOUT_RETURN);
       { // All defaults, except timeout_return
-        test_truth(gearman_is_allocated(gear));
+        ASSERT_TRUE(gearman_is_allocated(gear));
         test_false(gearman_is_non_blocking(gear->impl()));
-        test_truth(gear->impl()->options.packet_init);
+        ASSERT_TRUE(gear->impl()->options.packet_init);
         test_false(gear->impl()->options.change);
-        test_true(gear->impl()->options.grab_uniq);
-        test_truth(gear->impl()->options.timeout_return);
+        ASSERT_TRUE(gear->impl()->options.grab_uniq);
+        ASSERT_TRUE(gear->impl()->options.timeout_return);
       }
       gearman_worker_add_options(gear, (gearman_worker_options_t)(GEARMAN_WORKER_NON_BLOCKING|GEARMAN_WORKER_GRAB_UNIQ));
       { // GEARMAN_WORKER_NON_BLOCKING set to default, by default.
-        test_truth(gearman_is_allocated(gear));
-        test_truth(gearman_is_non_blocking(gear->impl()));
-        test_truth(gear->impl()->options.packet_init);
+        ASSERT_TRUE(gearman_is_allocated(gear));
+        ASSERT_TRUE(gearman_is_non_blocking(gear->impl()));
+        ASSERT_TRUE(gear->impl()->options.packet_init);
         test_false(gear->impl()->options.change);
-        test_truth(gear->impl()->options.grab_uniq);
-        test_truth(gear->impl()->options.timeout_return);
+        ASSERT_TRUE(gear->impl()->options.grab_uniq);
+        ASSERT_TRUE(gear->impl()->options.timeout_return);
       }
     }
     /*
@@ -423,30 +434,30 @@ static test_return_t option_test(void *)
     {
       gearman_worker_set_options(gear, default_options);
       { // See if we return to defaults
-        test_truth(gearman_is_allocated(gear));
+        ASSERT_TRUE(gearman_is_allocated(gear));
         test_false(gearman_is_non_blocking(gear->impl()));
-        test_truth(gear->impl()->options.packet_init);
+        ASSERT_TRUE(gear->impl()->options.packet_init);
         test_false(gear->impl()->options.change);
-        test_true(gear->impl()->options.grab_uniq);
+        ASSERT_TRUE(gear->impl()->options.grab_uniq);
         test_false(gear->impl()->options.timeout_return);
       }
       gearman_worker_add_options(gear, GEARMAN_WORKER_TIMEOUT_RETURN);
       { // All defaults, except timeout_return
-        test_truth(gearman_is_allocated(gear));
+        ASSERT_TRUE(gearman_is_allocated(gear));
         test_false(gearman_is_non_blocking(gear->impl()));
-        test_truth(gear->impl()->options.packet_init);
+        ASSERT_TRUE(gear->impl()->options.packet_init);
         test_false(gear->impl()->options.change);
-        test_true(gear->impl()->options.grab_uniq);
-        test_truth(gear->impl()->options.timeout_return);
+        ASSERT_TRUE(gear->impl()->options.grab_uniq);
+        ASSERT_TRUE(gear->impl()->options.timeout_return);
       }
       gearman_worker_add_options(gear, (gearman_worker_options_t)(GEARMAN_WORKER_TIMEOUT_RETURN|GEARMAN_WORKER_GRAB_UNIQ));
       { // GEARMAN_WORKER_NON_BLOCKING set to default, by default.
-        test_truth(gearman_is_allocated(gear));
+        ASSERT_TRUE(gearman_is_allocated(gear));
         test_false(gearman_is_non_blocking(gear->impl()));
-        test_truth(gear->impl()->options.packet_init);
+        ASSERT_TRUE(gear->impl()->options.packet_init);
         test_false(gear->impl()->options.change);
-        test_truth(gear->impl()->options.grab_uniq);
-        test_truth(gear->impl()->options.timeout_return);
+        ASSERT_TRUE(gear->impl()->options.grab_uniq);
+        ASSERT_TRUE(gear->impl()->options.timeout_return);
       }
     }
   }
@@ -508,7 +519,7 @@ static test_return_t gearman_worker_add_server_GEARMAN_GETADDRINFO_TEST(void *)
   if (libtest::check_dns())
   {
     gearman_worker_st *worker= gearman_worker_create(NULL);
-    test_true(worker);
+    ASSERT_TRUE(worker);
     ASSERT_EQ(gearman_worker_add_server(worker, "nonexist.gearman.info", libtest::default_port()), GEARMAN_GETADDRINFO);
     gearman_worker_free(worker);
   }
@@ -554,13 +565,13 @@ static test_return_t job_order_TEST(void *)
 
   long order_context= order_seed +1;
   gearman_function_t check_order_worker_TEST_FN= gearman_function_create(check_order_worker);
-  std::auto_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
-                                                           NULL,
-                                                           __func__,
-                                                           check_order_worker_TEST_FN,
-                                                           (void*)&order_context,
-                                                           gearman_worker_options_t(),
-                                                           0)); // timeout
+  std::unique_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
+                                                             NULL,
+                                                             __func__,
+                                                             check_order_worker_TEST_FN,
+                                                             (void*)&order_context,
+                                                             gearman_worker_options_t(),
+                                                             0)); // timeout
 
   {
     gearman_return_t ret;
@@ -745,22 +756,22 @@ static test_return_t error_return_TEST(void *)
                                            &task_attr, // gearman_task_attr_t
                                            &arg, // gearman_argument_t
                                            NULL); // context
-    test_truth(task);
+    ASSERT_TRUE(task);
 
     bool is_known;
     ASSERT_EQ(gearman_client_job_status(&client, gearman_task_job_handle(task), &is_known, NULL, NULL, NULL), GEARMAN_SUCCESS);
-    test_true(is_known);
+    ASSERT_TRUE(is_known);
     job_handles[int(x)].append(gearman_task_job_handle(task));
   }
 
   gearman_function_t error_return_TEST_FN= gearman_function_create(error_return_worker);
-  std::auto_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
-                                                           NULL,
-                                                           __func__,
-                                                           error_return_TEST_FN,
-                                                           NULL,
-                                                           gearman_worker_options_t(),
-                                                           0)); // timeout
+  std::unique_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
+                                                             NULL,
+                                                             __func__,
+                                                             error_return_TEST_FN,
+                                                             NULL,
+                                                             gearman_worker_options_t(),
+                                                             0)); // timeout
 
   for (gearman_return_t x= GEARMAN_IO_WAIT; int(x) < int(GEARMAN_MAX_RETURN); x= gearman_return_t((int(x) +1)))
   {
@@ -792,13 +803,13 @@ static test_return_t GEARMAN_ERROR_check_retry_TEST(void *)
 
   size_t count= 0;
   gearman_function_t GEARMAN_ERROR_FN= gearman_function_create(GEARMAN_ERROR_worker);
-  std::auto_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
-                                                           NULL,
-                                                           __func__,
-                                                           GEARMAN_ERROR_FN,
-                                                           &count,
-                                                           gearman_worker_options_t(),
-                                                           0)); // timeout
+  std::unique_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
+                                                             NULL,
+                                                             __func__,
+                                                             GEARMAN_ERROR_FN,
+                                                             &count,
+                                                             gearman_worker_options_t(),
+                                                             0)); // timeout
 
   gearman_task_st *task= gearman_execute(&client,
                                          test_literal_param(__func__),
@@ -827,13 +838,13 @@ static test_return_t GEARMAN_ERROR_always_return_TEST(void *)
 
   size_t count= 0;
   gearman_function_t GEARMAN_ERROR_FN= gearman_function_create(GEARMAN_ERROR_worker);
-  std::auto_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
-                                                           NULL,
-                                                           __func__,
-                                                           GEARMAN_ERROR_FN,
-                                                           &count,
-                                                           gearman_worker_options_t(),
-                                                           0)); // timeout
+  std::unique_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
+                                                             NULL,
+                                                             __func__,
+                                                             GEARMAN_ERROR_FN,
+                                                             &count,
+                                                             gearman_worker_options_t(),
+                                                             0)); // timeout
 
   std::vector<gearman_task_st*> tasks;
   for (size_t x= 0; x < 24; x++)
@@ -844,7 +855,7 @@ static test_return_t GEARMAN_ERROR_always_return_TEST(void *)
                                            NULL, // gearman_task_attr_t
                                            NULL, // gearman_argument_t
                                            NULL); // context
-    test_truth(task);
+    ASSERT_TRUE(task);
     tasks.push_back(task);
   }
 
@@ -870,13 +881,13 @@ static test_return_t GEARMAN_ERROR_return_TEST(void *)
 
   size_t count= 0;
   gearman_function_t GEARMAN_ERROR_FN= gearman_function_create(GEARMAN_ERROR_limit_worker);
-  std::auto_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
-                                                           NULL,
-                                                           __func__,
-                                                           GEARMAN_ERROR_FN,
-                                                           &count,
-                                                           gearman_worker_options_t(),
-                                                           0)); // timeout
+  std::unique_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
+                                                             NULL,
+                                                             __func__,
+                                                             GEARMAN_ERROR_FN,
+                                                             &count,
+                                                             gearman_worker_options_t(),
+                                                             0)); // timeout
 
   for (size_t x= 0; x < 24; x++)
   {
@@ -887,7 +898,7 @@ static test_return_t GEARMAN_ERROR_return_TEST(void *)
                                            NULL, // gearman_task_attr_t
                                            NULL, // gearman_argument_t
                                            NULL); // context
-    test_truth(task);
+    ASSERT_TRUE(task);
 
     gearman_return_t rc;
     bool is_known;
@@ -899,7 +910,7 @@ static test_return_t GEARMAN_ERROR_return_TEST(void *)
     test_zero(count); // Since we hit zero we know that we ran enough times.
 
     gearman_result_st *result= gearman_task_result(task);
-    test_true(result);
+    ASSERT_TRUE(result);
     test_memcmp("OK", gearman_result_value(result), strlen("ok"));
   }
 
@@ -913,13 +924,13 @@ static test_return_t GEARMAN_FAIL_return_TEST(void *)
   ASSERT_EQ(GEARMAN_SUCCESS, gearman_client_echo(&client, test_literal_param(__func__)));
 
   gearman_function_t error_return_TEST_FN= gearman_function_create(error_return_worker);
-  std::auto_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
-                                                           NULL,
-                                                           __func__,
-                                                           error_return_TEST_FN,
-                                                           NULL,
-                                                           gearman_worker_options_t(),
-                                                           0)); // timeout
+  std::unique_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
+                                                             NULL,
+                                                             __func__,
+                                                             error_return_TEST_FN,
+                                                             NULL,
+                                                             gearman_worker_options_t(),
+                                                             0)); // timeout
 
   int count= 3;
   while(--count)
@@ -932,7 +943,7 @@ static test_return_t GEARMAN_FAIL_return_TEST(void *)
                                            NULL, // gearman_task_attr_t
                                            &arg, // gearman_argument_t
                                            NULL); // context
-    test_truth(task);
+    ASSERT_TRUE(task);
 
     gearman_return_t rc;
     bool is_known;
@@ -951,13 +962,13 @@ static test_return_t GEARMAN_FAIL_return_TEST(void *)
 static test_return_t gearman_job_send_exception_mass_TEST(void *)
 {
   gearman_function_t call_exception_WORKER_FN= gearman_function_create(call_exception_WORKER);
-  std::auto_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
-                                                           NULL,
-                                                           "exception",
-                                                           call_exception_WORKER_FN,
-                                                           NULL,
-                                                           gearman_worker_options_t(),
-                                                           0)); // timeout
+  std::unique_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
+                                                             NULL,
+                                                             "exception",
+                                                             call_exception_WORKER_FN,
+                                                             NULL,
+                                                             gearman_worker_options_t(),
+                                                             0)); // timeout
 
   std::vector<gearman_task_st*> tasks;
   libgearman::Client client(libtest::default_port());
@@ -1034,13 +1045,13 @@ static test_return_t gearman_job_send_exception_mass_TEST(void *)
 static test_return_t gearman_job_client_TEST(void *)
 {
   gearman_function_t call_client_echo_WORKER_FN= gearman_function_create(client_echo_WORKER);
-  std::auto_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
-                                                           NULL,
-                                                           "client_echo",
-                                                           call_client_echo_WORKER_FN,
-                                                           NULL,
-                                                           gearman_worker_options_t(),
-                                                           0)); // timeout
+  std::unique_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
+                                                             NULL,
+                                                             "client_echo",
+                                                             call_client_echo_WORKER_FN,
+                                                             NULL,
+                                                             gearman_worker_options_t(),
+                                                             0)); // timeout
 
   std::vector<gearman_task_st*> tasks;
   libgearman::Client client(libtest::default_port());
@@ -1113,13 +1124,13 @@ static test_return_t gearman_job_send_exception_TEST(void *)
   gearman_client_add_options(&client, GEARMAN_CLIENT_EXCEPTION);
 
   gearman_function_t exception_WORKER_FN= gearman_function_create(exception_WORKER);
-  std::auto_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
-                                                           NULL,
-                                                           __func__,
-                                                           exception_WORKER_FN,
-                                                           NULL,
-                                                           gearman_worker_options_t(),
-                                                           0)); // timeout
+  std::unique_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
+                                                             NULL,
+                                                             __func__,
+                                                             exception_WORKER_FN,
+                                                             NULL,
+                                                             gearman_worker_options_t(),
+                                                             0)); // timeout
 
   gearman_return_t ret;
   gearman_task_st *task= gearman_client_add_task(&client, NULL, NULL,
@@ -1160,16 +1171,16 @@ static test_return_t gearman_client_job_status_is_known_TEST(void *)
   bool is_known;
   ASSERT_EQ(gearman_client_job_status(&client, job_handle, &is_known, NULL, NULL, NULL), GEARMAN_SUCCESS);
 
-  test_true(is_known);
+  ASSERT_TRUE(is_known);
 
   gearman_function_t echo_or_react_worker_v2_FN= gearman_function_create(echo_or_react_worker_v2);
-  std::auto_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
-                                                           NULL,
-                                                           __func__,
-                                                           echo_or_react_worker_v2_FN,
-                                                           NULL,
-                                                           gearman_worker_options_t(),
-                                                           0)); // timeout
+  std::unique_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
+                                                             NULL,
+                                                             __func__,
+                                                             echo_or_react_worker_v2_FN,
+                                                             NULL,
+                                                             gearman_worker_options_t(),
+                                                             0)); // timeout
 
   return TEST_SUCCESS;
 }
@@ -1191,7 +1202,7 @@ static test_return_t abandoned_worker_test(void *)
   universal.timeout= 3000;
 
   gearman_connection_st *connection1;
-  test_truth(connection1= gearman_connection_create(universal, NULL, default_port()));
+  ASSERT_TRUE(connection1= gearman_connection_create(universal, NULL, default_port()));
 
   gearman_packet_st packet;
   args[0]= "abandoned_worker";
@@ -1216,14 +1227,14 @@ static test_return_t abandoned_worker_test(void *)
 
   connection1->receiving(packet, ret, false);
 
-  test_truth(not (ret != GEARMAN_SUCCESS or packet.command != GEARMAN_COMMAND_JOB_ASSIGN));
+  ASSERT_TRUE(not (ret != GEARMAN_SUCCESS or packet.command != GEARMAN_COMMAND_JOB_ASSIGN));
 
   test_strcmp(job_handle, packet.arg[0]); // unexepcted job
 
   gearman_packet_free(&packet);
 
   gearman_connection_st *connection2;
-  test_truth(connection2= gearman_connection_create(universal, NULL, default_port()));
+  ASSERT_TRUE(connection2= gearman_connection_create(universal, NULL, default_port()));
 
   args[0]= "abandoned_worker";
   args_size[0]= strlen("abandoned_worker");
@@ -1249,7 +1260,7 @@ static test_return_t abandoned_worker_test(void *)
 
   gearman_universal_set_timeout(universal, 1000);
   connection2->receiving(packet, ret, false);
-  test_truth(not (ret != GEARMAN_SUCCESS or packet.command != GEARMAN_COMMAND_ERROR));
+  ASSERT_TRUE(not (ret != GEARMAN_SUCCESS or packet.command != GEARMAN_COMMAND_ERROR));
 
   delete connection1;
   delete connection2;
@@ -1439,7 +1450,7 @@ static test_return_t gearman_worker_work_with_test(int timeout, gearman_worker_o
     gearman_worker_add_options(&worker, option);
     if (option == GEARMAN_WORKER_NON_BLOCKING)
     {
-      test_true(gearman_worker_options(&worker) & GEARMAN_WORKER_NON_BLOCKING);
+      ASSERT_TRUE(gearman_worker_options(&worker) & GEARMAN_WORKER_NON_BLOCKING);
     }
   }
 
@@ -1513,8 +1524,8 @@ static test_return_t gearman_worker_context_test(void *)
 
   int *ptr= (int *)gearman_worker_context(&worker);
 
-  test_truth(ptr == &value);
-  test_truth(*ptr == value);
+  ASSERT_TRUE(ptr == &value);
+  ASSERT_TRUE(*ptr == value);
   gearman_worker_set_context(&worker, NULL);
 
   return TEST_SUCCESS;
@@ -1524,7 +1535,7 @@ static test_return_t gearman_worker_check_options_GEARMAN_WORKER_GRAB_UNIQ(void
 {
   libgearman::Worker worker;
 
-  test_true(worker->impl()->options.grab_uniq);
+  ASSERT_TRUE(worker->impl()->options.grab_uniq);
 
   return TEST_SUCCESS;
 }
@@ -1590,12 +1601,12 @@ static test_return_t gearman_worker_add_options_GEARMAN_WORKER_GRAB_UNIQ(void *)
                gearman_worker_add_function(&worker, function_name, 0, check_unique_worker, NULL));
 
   gearman_worker_add_options(&worker, GEARMAN_WORKER_GRAB_UNIQ);
-  test_true(worker->impl()->options.grab_uniq);
+  ASSERT_TRUE(worker->impl()->options.grab_uniq);
 
   gearman_return_t rc;
   gearman_job_st *job= gearman_worker_grab_job(&worker, NULL, &rc);
   ASSERT_EQ(GEARMAN_SUCCESS, rc);
-  test_truth(job);
+  ASSERT_TRUE(job);
 
   size_t size= 0;
   void *result= check_unique_worker(job, NULL, &size, &rc);
@@ -1641,14 +1652,14 @@ static test_return_t gearman_worker_add_options_GEARMAN_WORKER_GRAB_UNIQ_worker_
               GEARMAN_SUCCESS);
   }
 
-  test_true(worker->impl()->options.grab_uniq);
+  ASSERT_TRUE(worker->impl()->options.grab_uniq);
   gearman_worker_add_options(&worker, GEARMAN_WORKER_GRAB_UNIQ);
-  test_truth(worker->impl()->options.grab_uniq);
+  ASSERT_TRUE(worker->impl()->options.grab_uniq);
 
   gearman_worker_set_timeout(&worker, 400);
   ASSERT_EQ(gearman_worker_work(&worker), GEARMAN_SUCCESS);
 
-  test_truth(success);
+  ASSERT_TRUE(success);
 
 
   return TEST_SUCCESS;
@@ -1662,13 +1673,13 @@ static test_return_t _increase_TEST(gearman_function_t &func, gearman_client_opt
 
   gearman_client_add_options(&client, options);
 
-  std::auto_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
-                                                           NULL,
-                                                           __func__,
-                                                           func,
-                                                           NULL,
-                                                           gearman_worker_options_t(),
-                                                           0)); // timeout
+  std::unique_ptr<worker_handle_st> handle(test_worker_start(libtest::default_port(),
+                                                             NULL,
+                                                             __func__,
+                                                             func,
+                                                             NULL,
+                                                             gearman_worker_options_t(),
+                                                             0)); // timeout
 
   size_t max_block_size= 4;
   if (libtest::is_massive())
@@ -1696,7 +1707,7 @@ static test_return_t _increase_TEST(gearman_function_t &func, gearman_client_opt
                                            NULL, // gearman_task_attr_t
                                            &value, // gearman_argument_t
                                            NULL); // context
-    test_truth(task);
+    ASSERT_TRUE(task);
 
     gearman_return_t rc;
     do {
@@ -1786,6 +1797,57 @@ static test_return_t gearman_worker_set_timeout_FAILOVER_TEST(void *)
   return TEST_SUCCESS;
 }
 
+static test_return_t worker_connect_too_multiple_server_TEST(void *)
+{
+#if 0
+  libgearman::Worker worker(libtest::default_port());
+
+  // Now add a port which we do not have a server running on
+  ASSERT_EQ(GEARMAN_SUCCESS, gearman_worker_add_server(&worker, NULL, second_port));
+
+  gearman_function_t worker_fn= gearman_function_create(echo_specific_worker);
+  ASSERT_EQ(GEARMAN_SUCCESS, gearman_worker_define_function(&worker,
+                                                            __func__, strlen(__func__),
+                                                            worker_fn,
+                                                            0,
+                                                            NULL));
+
+  std::unique_ptr<worker_handle_st> handle(worker_run(worker));
+
+  libgearman::Client client_one(libtest::default_port());
+
+  libgearman::Client client_two(libtest::default_port());
+
+  {
+    size_t result_size;
+    gearman_return_t rc;
+    void* result= gearman_client_do(&client_one,
+                                    __func__,
+                                    NULL,
+                                    NULL, 0, // workload, workload_size
+                                    &result_size,
+                                    &rc);
+    ASSERT_TRUE(result_size);
+    ASSERT_NOT_NULL(result);
+  }
+
+  {
+    size_t result_size;
+    gearman_return_t rc;
+    void* result= gearman_client_do(&client_two,
+                                    __func__,
+                                    NULL,
+                                    NULL, 0, // workload, workload_size
+                                    &result_size,
+                                    &rc);
+    ASSERT_TRUE(result_size);
+    ASSERT_NOT_NULL(result);
+  }
+
+#endif
+  return TEST_SUCCESS;
+}
+
 /*********************** World functions **************************************/
 
 static void *world_create(server_startup_st& servers, test_return_t&)
@@ -1837,6 +1899,7 @@ test_st worker_TESTS[] ={
   {"gearman_job_client()", 0, gearman_job_client_TEST },
   {"job order", 0, job_order_TEST },
   {"job background order", 0, job_order_background_TEST },
+  {"check worker's connection to multiple servers", 0, worker_connect_too_multiple_server_TEST },
   {"echo_max", 0, echo_max_test },
   {"abandoned_worker", 0, abandoned_worker_test },
   {0, 0, 0}
